@@ -11,11 +11,7 @@ class ContextHelper(object):
 
     CONFIG_FILE_PATTERN = "kubeflow*"
 
-    def __init__(
-        self,
-        metadata,
-        env,
-    ):
+    def __init__(self, metadata, env):
         self._metadata = metadata
         self._env = env
 
@@ -59,21 +55,12 @@ class ContextHelper(object):
             )
 
     @staticmethod
-    def init(
-        metadata,
-        env,
-    ):
+    def init(metadata, env):
         version = VersionInfo.parse(kedro_version)
         if version.match(">=0.17.0"):
-            return ContextHelper(
-                metadata,
-                env,
-            )
+            return ContextHelper(metadata, env)
         else:
-            return ContextHelper16(
-                metadata,
-                env,
-            )
+            return ContextHelper16(metadata, env)
 
 
 class ContextHelper16(ContextHelper):
